Learn R Programming

rglobi (version 0.2.4)

get_prey_of: Get a List of Prey for given Predator Taxon

Description

Get a List of Prey for given Predator Taxon

Usage

get_prey_of(taxon = "Homo sapiens", opts = list())

Arguments

taxon
scientific name of predator taxon. Can be any taxonomic rank (e.g. Homo sapiens, Animalia)
opts
list of named options to configure GloBI API

Value

  • list of recorded predator-prey interactions that involve the desired predator taxon

See Also

Other interactions: get_child_taxa; get_interaction_matrix; get_interaction_table; get_interaction_types; get_interactions_by_taxa; get_interactions; get_predators_of

Examples

Run this code
get_prey_of("Homo sapiens")
get_prey_of("Primates")

Run the code above in your browser using DataLab